Module: ActiveAdmin::ResourceController::DataAccess
- Included in:
- ActiveAdmin::ResourceController
- Defined in:
- lib/active_admin/resource_controller/data_access.rb
Overview
This module overrides most of the data access methods in Inherited Resources to provide Active Admin with it’s data.
The module also deals with authorization and resource callbacks.
Constant Summary collapse
- COLLECTION_APPLIES =
[ :authorization_scope, :sorting, :filtering, :scoping, :includes, :pagination, :collection_decorator ].freeze
Instance Method Summary collapse
-
#apply_authorization_scope(collection) ⇒ ActiveRecord::Relation
protected
Gives the authorization library a change to pre-scope the collection.
-
#apply_decorations(resource) ⇒ ActiveRecord::Base
protected
Resource.
-
#apply_filtering(chain) ⇒ Object
protected
Applies any Ransack search methods to the currently scoped collection.
- #apply_includes(chain) ⇒ Object protected
- #apply_pagination(chain) ⇒ Object protected
- #apply_scoping(chain) ⇒ Object protected
- #apply_sorting(chain) ⇒ Object protected
-
#assign_attributes(resource, attributes) ⇒ ActiveRecord::Base
protected
Resource.
-
#build_new_resource ⇒ ActiveRecord::Base
protected
Builds a new resource.
-
#build_resource ⇒ ActiveRecord::Base
protected
Builds, memoize and authorize a new instance of the resource.
-
#collection ⇒ ActiveRecord::Relation
protected
Retrieve, memoize and authorize the current collection from the db.
- #collection_applies(options = {}) ⇒ Object protected
- #collection_before_scope ⇒ Object protected
- #configured_per_page ⇒ Object protected
-
#create_resource(object) ⇒ void
protected
Calls all the appropriate callbacks and then creates the new resource.
- #current_scope ⇒ Object protected
-
#destroy_resource(object) ⇒ void
protected
Destroys an object from the database and calls appropriate callbacks.
- #dynamic_per_page ⇒ Object protected
-
#find_collection(options = {}) ⇒ ActiveRecord::Relation
protected
Does the actual work of retrieving the current collection from the db.
-
#find_resource ⇒ ActiveRecord::Base
protected
Does the actual work of finding a resource in the database.
- #per_page ⇒ Object protected
-
#resource ⇒ ActiveRecord::Base
protected
Retrieve, memoize and authorize a resource based on params.
-
#save_resource(object) ⇒ void
protected
Calls all the appropriate callbacks and then saves the new resource.
-
#scoped_collection ⇒ Object
protected
Override this method in your controllers to modify the start point of our searches and index.
- #smart_resource_url ⇒ String protected
-
#update_resource(object, attributes) ⇒ void
protected
Update an object with the given attributes.
Instance Method Details
#apply_authorization_scope(collection) ⇒ ActiveRecord::Relation (protected)
Gives the authorization library a change to pre-scope the collection.
In the case of the CanCan adapter, it calls #accessible_by on the collection.
197 198 199 200 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 197 def (collection) action_name = (params[:action]) .scope_collection(collection, action_name) end |
#apply_decorations(resource) ⇒ ActiveRecord::Base (protected)
Returns resource.
297 298 299 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 297 def apply_decorations(resource) apply_decorator(resource) end |
#apply_filtering(chain) ⇒ Object (protected)
Applies any Ransack search methods to the currently scoped collection. Both search and ransack are provided, but we use ransack to prevent conflicts.
215 216 217 218 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 215 def apply_filtering(chain) @search = chain.ransack(params[:q] || {}) @search.result end |
#apply_includes(chain) ⇒ Object (protected)
230 231 232 233 234 235 236 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 230 def apply_includes(chain) if active_admin_config.includes.any? chain.includes *active_admin_config.includes else chain end end |
#apply_pagination(chain) ⇒ Object (protected)
250 251 252 253 254 255 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 250 def apply_pagination(chain) page_method_name = Kaminari.config.page_method_name page = params[Kaminari.config.param_name] chain.public_send(page_method_name, page).per(per_page) end |
#apply_scoping(chain) ⇒ Object (protected)
220 221 222 223 224 225 226 227 228 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 220 def apply_scoping(chain) @collection_before_scope = chain if current_scope scope_chain(current_scope, chain) else chain end end |
#apply_sorting(chain) ⇒ Object (protected)
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 202 def apply_sorting(chain) params[:order] ||= active_admin_config.sort_order order_clause = active_admin_config.order_clause.new(active_admin_config, params[:order]) if order_clause.valid? order_clause.apply(chain) else chain # just return the chain end end |
#assign_attributes(resource, attributes) ⇒ ActiveRecord::Base (protected)
Returns resource.
284 285 286 287 288 289 290 291 292 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 284 def assign_attributes(resource, attributes) if resource.respond_to?(:assign_attributes) resource.assign_attributes(*attributes) else resource.attributes = attributes[0] end resource end |
#build_new_resource ⇒ ActiveRecord::Base (protected)
Builds a new resource. This method uses the method_for_build provided by Inherited Resources.
130 131 132 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 130 def build_new_resource scoped_collection.send method_for_build, *resource_params end |
#build_resource ⇒ ActiveRecord::Base (protected)
Builds, memoize and authorize a new instance of the resource. The actual work of building the new instance is delegated to the #build_new_resource method.
This method is used to instantiate and authorize new resources in the new and create controller actions.
115 116 117 118 119 120 121 122 123 124 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 115 def build_resource get_resource_ivar || begin resource = build_new_resource resource = apply_decorations(resource) run_build_callbacks resource resource set_resource_ivar resource end end |
#collection ⇒ ActiveRecord::Relation (protected)
Retrieve, memoize and authorize the current collection from the db. This method delegates the finding of the collection to #find_collection.
Once #collection has been called, the collection is available using either the @collection instance variable or an instance variable named after the resource that the collection is for. eg: Post => @post.
40 41 42 43 44 45 46 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 40 def collection get_collection_ivar || begin collection = find_collection Authorization::READ, active_admin_config.resource_class set_collection_ivar collection end end |
#collection_applies(options = {}) ⇒ Object (protected)
257 258 259 260 261 262 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 257 def collection_applies( = {}) only = Array(.fetch(:only, COLLECTION_APPLIES)) except = Array(.fetch(:except, [])) COLLECTION_APPLIES & only - except end |
#collection_before_scope ⇒ Object (protected)
238 239 240 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 238 def collection_before_scope @collection_before_scope end |
#configured_per_page ⇒ Object (protected)
276 277 278 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 276 def configured_per_page Array(active_admin_config.per_page).first end |
#create_resource(object) ⇒ void (protected)
This method returns an undefined value.
Calls all the appropriate callbacks and then creates the new resource.
139 140 141 142 143 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 139 def create_resource(object) run_create_callbacks object do save_resource(object) end end |
#current_scope ⇒ Object (protected)
242 243 244 245 246 247 248 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 242 def current_scope @current_scope ||= if params[:scope] active_admin_config.get_scope_by_id(params[:scope]) else active_admin_config.default_scope(self) end end |
#destroy_resource(object) ⇒ void (protected)
This method returns an undefined value.
Destroys an object from the database and calls appropriate callbacks.
177 178 179 180 181 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 177 def destroy_resource(object) run_destroy_callbacks object do object.destroy end end |
#dynamic_per_page ⇒ Object (protected)
272 273 274 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 272 def dynamic_per_page params[:per_page] || @per_page end |
#find_collection(options = {}) ⇒ ActiveRecord::Relation (protected)
Does the actual work of retrieving the current collection from the db. This is a great method to override if you would like to perform some additional db # work before your controller returns and authorizes the collection.
55 56 57 58 59 60 61 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 55 def find_collection( = {}) collection = scoped_collection collection_applies().each do |applyer| collection = send("apply_#{applyer}", collection) end collection end |
#find_resource ⇒ ActiveRecord::Base (protected)
Does the actual work of finding a resource in the database. This method uses the finder method as defined in InheritedResources.
102 103 104 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 102 def find_resource scoped_collection.send method_for_find, params[:id] end |
#per_page ⇒ Object (protected)
264 265 266 267 268 269 270 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 264 def per_page if active_admin_config.paginate dynamic_per_page || configured_per_page else active_admin_config.max_per_page end end |
#resource ⇒ ActiveRecord::Base (protected)
Retrieve, memoize and authorize a resource based on params. The actual work of finding the resource is done in #find_resource.
This method is used on all the member actions:
* show
* edit
* update
* destroy
88 89 90 91 92 93 94 95 96 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 88 def resource get_resource_ivar || begin resource = find_resource resource = apply_decorations(resource) resource set_resource_ivar resource end end |
#save_resource(object) ⇒ void (protected)
This method returns an undefined value.
Calls all the appropriate callbacks and then saves the new resource.
150 151 152 153 154 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 150 def save_resource(object) run_save_callbacks object do object.save end end |
#scoped_collection ⇒ Object (protected)
Override this method in your controllers to modify the start point of our searches and index.
This method should return an ActiveRecord::Relation object so that the searching and filtering can be applied on top
Note, unless you are doing something special, you should use the scope_to method from the Scoping module instead of overriding this method.
73 74 75 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 73 def scoped_collection end_of_association_chain end |
#smart_resource_url ⇒ String (protected)
302 303 304 305 306 307 308 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 302 def smart_resource_url if create_another? new_resource_url(create_another: params[:create_another]) else super end end |
#update_resource(object, attributes) ⇒ void (protected)
This method returns an undefined value.
Update an object with the given attributes. Also calls the appropriate callbacks for update action.
166 167 168 169 170 171 172 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 166 def update_resource(object, attributes) object = assign_attributes(object, attributes) run_update_callbacks object do save_resource(object) end end |